@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import asyncio
 import inspect
 import json
@@ -7,55 +9,29 @@ import os
 import socket
 import ssl
 import sys
+from collections.abc import Awaitable
+from configparser import RawConfigParser
 from pathlib import Path
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Awaitable,
-    Callable,
-    Dict,
-    List,
-    Optional,
-    Tuple,
-    Type,
-    Union,
-)
-
-from h11._connection import DEFAULT_MAX_INCOMPLETE_EVENT_SIZE
-
-from uvicorn.logging import TRACE_LOG_LEVEL
-
-if sys.version_info < (3, 8):  # pragma: py-gte-38
-    from typing_extensions import Literal
-else:  # pragma: py-lt-38
-    from typing import Literal
+from typing import IO, Any, Callable, Literal
 
 import click
 
-try:
-    import yaml
-except ImportError:  # pragma: no cover
-    # If the code below that depends on yaml is exercised, it will raise a NameError.
-    # Install the PyYAML package or the uvicorn[standard] optional dependencies to
-    # enable this functionality.
-    pass
-
+from uvicorn._compat import iscoroutinefunction
+from uvicorn._types import ASGIApplication
 from uvicorn.importer import ImportFromStringError, import_from_string
+from uvicorn.logging import TRACE_LOG_LEVEL
 from uvicorn.middleware.asgi2 import ASGI2Middleware
 from uvicorn.middleware.message_logger import MessageLoggerMiddleware
 from uvicorn.middleware.proxy_headers import ProxyHeadersMiddleware
 from uvicorn.middleware.wsgi import WSGIMiddleware
 
-if TYPE_CHECKING:
-    from asgiref.typing import ASGIApplication
-
 HTTPProtocolType = Literal["auto", "h11", "httptools"]
-WSProtocolType = Literal["auto", "none", "websockets", "wsproto"]
+WSProtocolType = Literal["auto", "none", "websockets", "websockets-sansio", "wsproto"]
 LifespanType = Literal["auto", "on", "off"]
-LoopSetupType = Literal["none", "auto", "asyncio", "uvloop"]
+LoopFactoryType = Literal["none", "auto", "asyncio", "uvloop"]
 InterfaceType = Literal["auto", "asgi3", "asgi2", "wsgi"]
 
-LOG_LEVELS: Dict[str, int] = {
+LOG_LEVELS: dict[str, int] = {
     "critical": logging.CRITICAL,
     "error": logging.ERROR,
     "warning": logging.WARNING,
@@ -63,33 +39,34 @@ LOG_LEVELS: Dict[str, int] = {
     "debug": logging.DEBUG,
     "trace": TRACE_LOG_LEVEL,
 }
-HTTP_PROTOCOLS: Dict[HTTPProtocolType, str] = {
+HTTP_PROTOCOLS: dict[str, str] = {
     "auto": "uvicorn.protocols.http.auto:AutoHTTPProtocol",
     "h11": "uvicorn.protocols.http.h11_impl:H11Protocol",
     "httptools": "uvicorn.protocols.http.httptools_impl:HttpToolsProtocol",
 }
-WS_PROTOCOLS: Dict[WSProtocolType, Optional[str]] = {
+WS_PROTOCOLS: dict[str, str | None] = {
     "auto": "uvicorn.protocols.websockets.auto:AutoWebSocketsProtocol",
     "none": None,
     "websockets": "uvicorn.protocols.websockets.websockets_impl:WebSocketProtocol",
+    "websockets-sansio": "uvicorn.protocols.websockets.websockets_sansio_impl:WebSocketsSansIOProtocol",
     "wsproto": "uvicorn.protocols.websockets.wsproto_impl:WSProtocol",
 }
-LIFESPAN: Dict[LifespanType, str] = {
+LIFESPAN: dict[str, str] = {
     "auto": "uvicorn.lifespan.on:LifespanOn",
     "on": "uvicorn.lifespan.on:LifespanOn",
     "off": "uvicorn.lifespan.off:LifespanOff",
 }
-LOOP_SETUPS: Dict[LoopSetupType, Optional[str]] = {
+LOOP_FACTORIES: dict[str, str | None] = {
     "none": None,
-    "auto": "uvicorn.loops.auto:auto_loop_setup",
-    "asyncio": "uvicorn.loops.asyncio:asyncio_setup",
-    "uvloop": "uvicorn.loops.uvloop:uvloop_setup",
+    "auto": "uvicorn.loops.auto:auto_loop_factory",
+    "asyncio": "uvicorn.loops.asyncio:asyncio_loop_factory",
+    "uvloop": "uvicorn.loops.uvloop:uvloop_loop_factory",
 }
-INTERFACES: List[InterfaceType] = ["auto", "asgi3", "asgi2", "wsgi"]
+INTERFACES: list[InterfaceType] = ["auto", "asgi3", "asgi2", "wsgi"]
 
 SSL_PROTOCOL_VERSION: int = ssl.PROTOCOL_TLS_SERVER
 
-LOGGING_CONFIG: Dict[str, Any] = {
+LOGGING_CONFIG: dict[str, Any] = {
     "version": 1,
     "disable_existing_loggers": False,
     "formatters": {
@@ -126,13 +103,13 @@ logger = logging.getLogger("uvicorn.error")
 
 
 def create_ssl_context(
-    certfile: Union[str, os.PathLike],
-    keyfile: Optional[Union[str, os.PathLike]],
-    password: Optional[str],
+    certfile: str | os.PathLike[str],
+    keyfile: str | os.PathLike[str] | None,
+    password: str | None,
     ssl_version: int,
     cert_reqs: int,
-    ca_certs: Optional[Union[str, os.PathLike]],
-    ciphers: Optional[str],
+    ca_certs: str | os.PathLike[str] | None,
+    ciphers: str | None,
 ) -> ssl.SSLContext:
     ctx = ssl.SSLContext(ssl_version)
     get_password = (lambda: password) if password else None
@@ -150,22 +127,20 @@ def is_dir(path: Path) -> bool:
         if not path.is_absolute():
             path = path.resolve()
         return path.is_dir()
-    except OSError:
+    except OSError:  # pragma: full coverage
         return False
 
 
-def resolve_reload_patterns(
-    patterns_list: List[str], directories_list: List[str]
-) -> Tuple[List[str], List[Path]]:
-    directories: List[Path] = list(set(map(Path, directories_list.copy())))
-    patterns: List[str] = patterns_list.copy()
+def resolve_reload_patterns(patterns_list: list[str], directories_list: list[str]) -> tuple[list[str], list[Path]]:
+    directories: list[Path] = list(set(map(Path, directories_list.copy())))
+    patterns: list[str] = patterns_list.copy()
 
     current_working_directory = Path.cwd()
     for pattern in patterns_list:
         # Special case for the .* pattern, otherwise this would only match
         # hidden directories which is probably undesired
         if pattern == ".*":
-            continue
+            continue  # pragma: py-not-linux
         patterns.append(pattern)
         if is_dir(Path(pattern)):
             directories.append(Path(pattern))
@@ -177,15 +152,13 @@ def resolve_reload_patterns(
     directories = list(set(directories))
     directories = list(map(Path, directories))
     directories = list(map(lambda x: x.resolve(), directories))
-    directories = list(
-        {reload_path for reload_path in directories if is_dir(reload_path)}
-    )
+    directories = list({reload_path for reload_path in directories if is_dir(reload_path)})
 
     children = []
     for j in range(len(directories)):
-        for k in range(j + 1, len(directories)):
+        for k in range(j + 1, len(directories)):  # pragma: full coverage
             if directories[j] in directories[k].parents:
-                children.append(directories[k])  # pragma: py-darwin
+                children.append(directories[k])
             elif directories[k] in directories[j].parents:
                 children.append(directories[j])
 
@@ -194,7 +167,7 @@ def resolve_reload_patterns(
     return list(set(patterns)), directories
 
 
-def _normalize_dirs(dirs: Union[List[str], str, None]) -> List[str]:
+def _normalize_dirs(dirs: list[str] | str | None) -> list[str]:
     if dirs is None:
         return []
     if isinstance(dirs, str):
@@ -205,52 +178,55 @@ def _normalize_dirs(dirs: Union[List[str], str, None]) -> List[str]:
 class Config:
     def __init__(
         self,
-        app: Union["ASGIApplication", Callable, str],
+        app: ASGIApplication | Callable[..., Any] | str,
         host: str = "127.0.0.1",
         port: int = 8000,
-        uds: Optional[str] = None,
-        fd: Optional[int] = None,
-        loop: LoopSetupType = "auto",
-        http: Union[Type[asyncio.Protocol], HTTPProtocolType] = "auto",
-        ws: Union[Type[asyncio.Protocol], WSProtocolType] = "auto",
+        uds: str | None = None,
+        fd: int | None = None,
+        loop: LoopFactoryType | str = "auto",
+        http: type[asyncio.Protocol] | HTTPProtocolType | str = "auto",
+        ws: type[asyncio.Protocol] | WSProtocolType | str = "auto",
         ws_max_size: int = 16 * 1024 * 1024,
-        ws_ping_interval: Optional[float] = 20.0,
-        ws_ping_timeout: Optional[float] = 20.0,
+        ws_max_queue: int = 32,
+        ws_ping_interval: float | None = 20.0,
+        ws_ping_timeout: float | None = 20.0,
         ws_per_message_deflate: bool = True,
         lifespan: LifespanType = "auto",
-        env_file: Optional[Union[str, os.PathLike]] = None,
-        log_config: Optional[Union[Dict[str, Any], str]] = LOGGING_CONFIG,
-        log_level: Optional[Union[str, int]] = None,
+        env_file: str | os.PathLike[str] | None = None,
+        log_config: dict[str, Any] | str | RawConfigParser | IO[Any] | None = LOGGING_CONFIG,
+        log_level: str | int | None = None,
         access_log: bool = True,
-        use_colors: Optional[bool] = None,
+        use_colors: bool | None = None,
         interface: InterfaceType = "auto",
         reload: bool = False,
-        reload_dirs: Optional[Union[List[str], str]] = None,
+        reload_dirs: list[str] | str | None = None,
         reload_delay: float = 0.25,
-        reload_includes: Optional[Union[List[str], str]] = None,
-        reload_excludes: Optional[Union[List[str], str]] = None,
-        workers: Optional[int] = None,
+        reload_includes: list[str] | str | None = None,
+        reload_excludes: list[str] | str | None = None,
+        workers: int | None = None,
         proxy_headers: bool = True,
         server_header: bool = True,
         date_header: bool = True,
-        forwarded_allow_ips: Optional[Union[List[str], str]] = None,
+        forwarded_allow_ips: list[str] | str | None = None,
         root_path: str = "",
-        limit_concurrency: Optional[int] = None,
-        limit_max_requests: Optional[int] = None,
+        limit_concurrency: int | None = None,
+        limit_max_requests: int | None = None,
         backlog: int = 2048,
         timeout_keep_alive: int = 5,
         timeout_notify: int = 30,
-        callback_notify: Optional[Callable[..., Awaitable[None]]] = None,
-        ssl_keyfile: Optional[str] = None,
-        ssl_certfile: Optional[Union[str, os.PathLike]] = None,
-        ssl_keyfile_password: Optional[str] = None,
+        timeout_graceful_shutdown: int | None = None,
+        timeout_worker_healthcheck: int = 5,
+        callback_notify: Callable[..., Awaitable[None]] | None = None,
+        ssl_keyfile: str | os.PathLike[str] | None = None,
+        ssl_certfile: str | os.PathLike[str] | None = None,
+        ssl_keyfile_password: str | None = None,
         ssl_version: int = SSL_PROTOCOL_VERSION,
         ssl_cert_reqs: int = ssl.CERT_NONE,
-        ssl_ca_certs: Optional[str] = None,
+        ssl_ca_certs: str | os.PathLike[str] | None = None,
         ssl_ciphers: str = "TLSv1",
-        headers: Optional[List[Tuple[str, str]]] = None,
+        headers: list[tuple[str, str]] | None = None,
         factory: bool = False,
-        h11_max_incomplete_event_size: int = DEFAULT_MAX_INCOMPLETE_EVENT_SIZE,
+        h11_max_incomplete_event_size: int | None = None,
     ):
         self.app = app
         self.host = host
@@ -261,6 +237,7 @@ class Config:
         self.http = http
         self.ws = ws
         self.ws_max_size = ws_max_size
+        self.ws_max_queue = ws_max_queue
         self.ws_ping_interval = ws_ping_interval
         self.ws_ping_timeout = ws_ping_timeout
         self.ws_per_message_deflate = ws_per_message_deflate
@@ -282,6 +259,8 @@ class Config:
         self.backlog = backlog
         self.timeout_keep_alive = timeout_keep_alive
         self.timeout_notify = timeout_notify
+        self.timeout_graceful_shutdown = timeout_graceful_shutdown
+        self.timeout_worker_healthcheck = timeout_worker_healthcheck
         self.callback_notify = callback_notify
         self.ssl_keyfile = ssl_keyfile
         self.ssl_certfile = ssl_certfile
@@ -290,25 +269,22 @@ class Config:
         self.ssl_cert_reqs = ssl_cert_reqs
         self.ssl_ca_certs = ssl_ca_certs
         self.ssl_ciphers = ssl_ciphers
-        self.headers: List[Tuple[str, str]] = headers or []
-        self.encoded_headers: List[Tuple[bytes, bytes]] = []
+        self.headers: list[tuple[str, str]] = headers or []
+        self.encoded_headers: list[tuple[bytes, bytes]] = []
         self.factory = factory
         self.h11_max_incomplete_event_size = h11_max_incomplete_event_size
 
         self.loaded = False
         self.configure_logging()
 
-        self.reload_dirs: List[Path] = []
-        self.reload_dirs_excludes: List[Path] = []
-        self.reload_includes: List[str] = []
-        self.reload_excludes: List[str] = []
+        self.reload_dirs: list[Path] = []
+        self.reload_dirs_excludes: list[Path] = []
+        self.reload_includes: list[str] = []
+        self.reload_excludes: list[str] = []
 
-        if (
-            reload_dirs or reload_includes or reload_excludes
-        ) and not self.should_reload:
+        if (reload_dirs or reload_includes or reload_excludes) and not self.should_reload:
             logger.warning(
-                "Current configuration will not reload as not all conditions are met,"
-                "please refer to documentation."
+                "Current configuration will not reload as not all conditions are met, please refer to documentation."
             )
 
         if self.should_reload:
@@ -316,30 +292,23 @@ class Config:
             reload_includes = _normalize_dirs(reload_includes)
             reload_excludes = _normalize_dirs(reload_excludes)
 
-            self.reload_includes, self.reload_dirs = resolve_reload_patterns(
-                reload_includes, reload_dirs
-            )
+            self.reload_includes, self.reload_dirs = resolve_reload_patterns(reload_includes, reload_dirs)
 
-            self.reload_excludes, self.reload_dirs_excludes = resolve_reload_patterns(
-                reload_excludes, []
-            )
+            self.reload_excludes, self.reload_dirs_excludes = resolve_reload_patterns(reload_excludes, [])
 
             reload_dirs_tmp = self.reload_dirs.copy()
 
             for directory in self.reload_dirs_excludes:
                 for reload_directory in reload_dirs_tmp:
-                    if (
-                        directory == reload_directory
-                        or directory in reload_directory.parents
-                    ):
+                    if directory == reload_directory or directory in reload_directory.parents:
                         try:
                             self.reload_dirs.remove(reload_directory)
-                        except ValueError:
+                        except ValueError:  # pragma: full coverage
                             pass
 
             for pattern in self.reload_excludes:
                 if pattern in self.reload_includes:
-                    self.reload_includes.remove(pattern)
+                    self.reload_includes.remove(pattern)  # pragma: full coverage
 
             if not self.reload_dirs:
                 if reload_dirs:
@@ -348,7 +317,7 @@ class Config:
                         + "directories, watching current working directory.",
                         reload_dirs,
                     )
-                self.reload_dirs = [Path(os.getcwd())]
+                self.reload_dirs = [Path.cwd()]
 
             logger.info(
                 "Will watch for changes in these directories: %s",
@@ -364,17 +333,18 @@ class Config:
         if workers is None and "WEB_CONCURRENCY" in os.environ:
             self.workers = int(os.environ["WEB_CONCURRENCY"])
 
-        self.forwarded_allow_ips: Union[List[str], str]
+        self.forwarded_allow_ips: list[str] | str
         if forwarded_allow_ips is None:
-            self.forwarded_allow_ips = os.environ.get(
-                "FORWARDED_ALLOW_IPS", "127.0.0.1"
-            )
+            self.forwarded_allow_ips = os.environ.get("FORWARDED_ALLOW_IPS", "127.0.0.1")
         else:
-            self.forwarded_allow_ips = forwarded_allow_ips
+            self.forwarded_allow_ips = forwarded_allow_ips  # pragma: full coverage
+
+        if self.reload and self.workers > 1:
+            logger.warning('"workers" flag is ignored when reloading is enabled.')
 
     @property
     def asgi_version(self) -> Literal["2.0", "3.0"]:
-        mapping: Dict[str, Literal["2.0", "3.0"]] = {
+        mapping: dict[str, Literal["2.0", "3.0"]] = {
             "asgi2": "2.0",
             "asgi3": "3.0",
             "wsgi": "3.0",
@@ -395,27 +365,25 @@ class Config:
         if self.log_config is not None:
             if isinstance(self.log_config, dict):
                 if self.use_colors in (True, False):
-                    self.log_config["formatters"]["default"][
-                        "use_colors"
-                    ] = self.use_colors
-                    self.log_config["formatters"]["access"][
-                        "use_colors"
-                    ] = self.use_colors
+                    self.log_config["formatters"]["default"]["use_colors"] = self.use_colors
+                    self.log_config["formatters"]["access"]["use_colors"] = self.use_colors
                 logging.config.dictConfig(self.log_config)
-            elif self.log_config.endswith(".json"):
+            elif isinstance(self.log_config, str) and self.log_config.endswith(".json"):
                 with open(self.log_config) as file:
                     loaded_config = json.load(file)
                     logging.config.dictConfig(loaded_config)
-            elif self.log_config.endswith((".yaml", ".yml")):
+            elif isinstance(self.log_config, str) and self.log_config.endswith((".yaml", ".yml")):
+                # Install the PyYAML package or the uvicorn[standard] optional
+                # dependencies to enable this functionality.
+                import yaml
+
                 with open(self.log_config) as file:
                     loaded_config = yaml.safe_load(file)
                     logging.config.dictConfig(loaded_config)
             else:
                 # See the note about fileConfig() here:
                 # https://docs.python.org/3/library/logging.config.html#configuration-file-format
-                logging.config.fileConfig(
-                    self.log_config, disable_existing_loggers=False
-                )
+                logging.config.fileConfig(self.log_config, disable_existing_loggers=False)
 
         if self.log_level is not None:
             if isinstance(self.log_level, str):
@@ -434,7 +402,7 @@ class Config:
 
         if self.is_ssl:
             assert self.ssl_certfile
-            self.ssl: Optional[ssl.SSLContext] = create_ssl_context(
+            self.ssl: ssl.SSLContext | None = create_ssl_context(
                 keyfile=self.ssl_keyfile,
                 certfile=self.ssl_certfile,
                 password=self.ssl_keyfile_password,
@@ -446,10 +414,7 @@ class Config:
         else:
             self.ssl = None
 
-        encoded_headers = [
-            (key.lower().encode("latin1"), value.encode("latin1"))
-            for key, value in self.headers
-        ]
+        encoded_headers = [(key.lower().encode("latin1"), value.encode("latin1")) for key, value in self.headers]
         self.encoded_headers = (
             [(b"server", b"uvicorn")] + encoded_headers
             if b"server" not in dict(encoded_headers) and self.server_header
@@ -457,14 +422,14 @@ class Config:
         )
 
         if isinstance(self.http, str):
-            http_protocol_class = import_from_string(HTTP_PROTOCOLS[self.http])
-            self.http_protocol_class: Type[asyncio.Protocol] = http_protocol_class
+            http_protocol_class = import_from_string(HTTP_PROTOCOLS.get(self.http, self.http))
+            self.http_protocol_class: type[asyncio.Protocol] = http_protocol_class
         else:
             self.http_protocol_class = self.http
 
         if isinstance(self.ws, str):
-            ws_protocol_class = import_from_string(WS_PROTOCOLS[self.ws])
-            self.ws_protocol_class: Optional[Type[asyncio.Protocol]] = ws_protocol_class
+            ws_protocol_class = import_from_string(WS_PROTOCOLS.get(self.ws, self.ws))
+            self.ws_protocol_class: type[asyncio.Protocol] | None = ws_protocol_class
         else:
             self.ws_protocol_class = self.ws
 
@@ -485,18 +450,17 @@ class Config:
         else:
             if not self.factory:
                 logger.warning(
-                    "ASGI app factory detected. Using it, "
-                    "but please consider setting the --factory flag explicitly."
+                    "ASGI app factory detected. Using it, but please consider setting the --factory flag explicitly."
                 )
 
         if self.interface == "auto":
             if inspect.isclass(self.loaded_app):
                 use_asgi_3 = hasattr(self.loaded_app, "__await__")
             elif inspect.isfunction(self.loaded_app):
-                use_asgi_3 = asyncio.iscoroutinefunction(self.loaded_app)
+                use_asgi_3 = iscoroutinefunction(self.loaded_app)
             else:
                 call = getattr(self.loaded_app, "__call__", None)
-                use_asgi_3 = asyncio.iscoroutinefunction(call)
+                use_asgi_3 = iscoroutinefunction(call)
             self.interface = "asgi3" if use_asgi_3 else "asgi2"
 
         if self.interface == "wsgi":
@@ -505,22 +469,35 @@ class Config:
         elif self.interface == "asgi2":
             self.loaded_app = ASGI2Middleware(self.loaded_app)
 
-        if logger.level <= TRACE_LOG_LEVEL:
+        if logger.getEffectiveLevel() <= TRACE_LOG_LEVEL:
             self.loaded_app = MessageLoggerMiddleware(self.loaded_app)
         if self.proxy_headers:
-            self.loaded_app = ProxyHeadersMiddleware(
-                self.loaded_app, trusted_hosts=self.forwarded_allow_ips
-            )
+            self.loaded_app = ProxyHeadersMiddleware(self.loaded_app, trusted_hosts=self.forwarded_allow_ips)
 
         self.loaded = True
 
     def setup_event_loop(self) -> None:
-        loop_setup: Optional[Callable] = import_from_string(LOOP_SETUPS[self.loop])
-        if loop_setup is not None:
-            loop_setup(use_subprocess=self.use_subprocess)
+        raise AttributeError(
+            "The `setup_event_loop` method was replaced by `get_loop_factory` in uvicorn 0.36.0.\n"
+            "None of those methods are supposed to be used directly. If you are doing it, please let me know here: "
+            "https://github.com/Kludex/uvicorn/discussions/2706. Thank you, and sorry for the inconvenience."
+        )
+
+    def get_loop_factory(self) -> Callable[[], asyncio.AbstractEventLoop] | None:
+        if self.loop in LOOP_FACTORIES:
+            loop_factory: Callable[..., Any] | None = import_from_string(LOOP_FACTORIES[self.loop])
+        else:
+            try:
+                return import_from_string(self.loop)
+            except ImportFromStringError as exc:
+                logger.error("Error loading custom loop setup function. %s" % exc)
+                sys.exit(1)
+        if loop_factory is None:
+            return None
+        return loop_factory(use_subprocess=self.use_subprocess)
 
     def bind_socket(self) -> socket.socket:
-        logger_args: List[Union[str, int]]
+        logger_args: list[str | int]
         if self.uds:  # pragma: py-win32
             path = self.uds
             sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
@@ -528,33 +505,25 @@ class Config:
                 sock.bind(path)
                 uds_perms = 0o666
                 os.chmod(self.uds, uds_perms)
-            except OSError as exc:
+            except OSError as exc:  # pragma: full coverage
                 logger.error(exc)
                 sys.exit(1)
 
             message = "Uvicorn running on unix socket %s (Press CTRL+C to quit)"
             sock_name_format = "%s"
-            color_message = (
-                "Uvicorn running on "
-                + click.style(sock_name_format, bold=True)
-                + " (Press CTRL+C to quit)"
-            )
+            color_message = "Uvicorn running on " + click.style(sock_name_format, bold=True) + " (Press CTRL+C to quit)"
             logger_args = [self.uds]
         elif self.fd:  # pragma: py-win32
             sock = socket.fromfd(self.fd, socket.AF_UNIX, socket.SOCK_STREAM)
             message = "Uvicorn running on socket %s (Press CTRL+C to quit)"
             fd_name_format = "%s"
-            color_message = (
-                "Uvicorn running on "
-                + click.style(fd_name_format, bold=True)
-                + " (Press CTRL+C to quit)"
-            )
+            color_message = "Uvicorn running on " + click.style(fd_name_format, bold=True) + " (Press CTRL+C to quit)"
             logger_args = [sock.getsockname()]
         else:
             family = socket.AF_INET
             addr_format = "%s://%s:%d"
 
-            if self.host and ":" in self.host:  # pragma: py-win32
+            if self.host and ":" in self.host:  # pragma: full coverage
                 # It's an IPv6 address.
                 family = socket.AF_INET6
                 addr_format = "%s://[%s]:%d"
@@ -563,18 +532,14 @@ class Config:
             sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
             try:
                 sock.bind((self.host, self.port))
-            except OSError as exc:
+            except OSError as exc:  # pragma: full coverage
                 logger.error(exc)
                 sys.exit(1)
 
             message = f"Uvicorn running on {addr_format} (Press CTRL+C to quit)"
-            color_message = (
-                "Uvicorn running on "
-                + click.style(addr_format, bold=True)
-                + " (Press CTRL+C to quit)"
-            )
+            color_message = "Uvicorn running on " + click.style(addr_format, bold=True) + " (Press CTRL+C to quit)"
             protocol_name = "https" if self.is_ssl else "http"
-            logger_args = [protocol_name, self.host, self.port]
+            logger_args = [protocol_name, self.host, sock.getsockname()[1]]
         logger.info(message, *logger_args, extra={"color_message": color_message})
         sock.set_inheritable(True)
         return sock
